#!/bin/bash
# This is an easy-to-use front end for qrencode, a QR code generator.
# both qrencode and zenity must be installed for this script to work.
# zenity is used to make the GUI dialog boxes, qrencode generates the QR code.
# In the apt-get package manager, run this command:
#      sudo apt-get install qrencode zenity
#
# Copyright (C) 2014 ssdclickofdeath
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without any warranty.


#Makes text box for QR code text, and saves it to the QRSTRING variable.
QRSTRING=$(zenity --entry \
                  --title="QR Encoder" \
                  --window-icon=qricon.png \
                  --text="Enter text to encode into a QR code." \
                  --width=300)

# Makes an empty variable to compare to QRSTRING to check for empty text entry.
BLANK=""

#Compares QRSTRING to BLANK to see if text entry field is blank.
#If the field is blank, make a dialog box showing the error.
if [ $QRSTRING = $BLANK ]; then
       zenity --info \
              --width=270 \
              --title="QR Encoder" \
              --window-icon=qricon.png \
              --text="The text entry field cannot be blank."
              exit 1;
fi
# Please enter some text inside the field. This program will now close.

#Sets the variable FILENAME to the name and path to save the QR code.
FILENAME=$(zenity --file-selection \
              --window-icon=qricon.png \
              --title="Save QR Code" \
              --save \
              --confirm-overwrite)

#Generates the QR code.
qrencode -o $FILENAME "$QRSTRING"

#Makes a dialog box showing the path and name of the QR code.
zenity --info \
       --title="File Saved" \
       --window-icon=qricon.png \
       --width=270 \
       --text="The QR Code was saved at $FILENAME."

#Exits the shell script.
exit 0;
